<template>
  <div>
    <div class="mb-4">
      <h3 class="font-semibold text-2xl text-gray-800">{{ localize('authorization') }}</h3>
      <div class="mt-2 mb-2" v-show="returned_error">
        <div class="bg-primary/[0.05] rounded-sm text-sm py-1 px-1.5 text-primary-dark font-semibold">
          <span>{{ error_title }}</span>
        </div>
      </div>
    </div>
    <div :class="{'space-y-5':true,'opacity-50 cursor-wait':loading}">
      <div class="space-y-2" v-show="returned_error !== 'recaptcha_v2_code_required'">
        <label class="text-sm font-medium text-gray-700 tracking-wide">
          {{ localize('email') }}
        </label>
        <input class=" w-full text-base px-4 py-2 border  border-gray-300 rounded-lg focus:outline-none focus:border-primary" type="text" placeholder="" v-model="login" :disabled="loading">
      </div>
      <div class="space-y-2" v-show="returned_error !== 'recaptcha_v2_code_required'">
        <label class="mb-5 text-sm font-medium text-gray-700 tracking-wide">
          {{ localize('password') }}
        </label>
        <input class="w-full content-center text-base px-4 py-2 border  border-gray-300 rounded-lg focus:outline-none focus:border-primary" type="password" placeholder="" v-model="password" :disabled="loading">
      </div>
      <div class="space-y-2" v-if="returned_error === 'recaptcha_v2_code_required'">
        <div class="recaptcha-v2-placeholder"></div>
      </div>
      <div class="flex items-center justify-between" v-show="returned_error !== 'recaptcha_v2_code_required'">
        <div class="flex items-center" v-show="false">
          <input id="remember_me" v-model="remember_me" type="checkbox" class="h-4 w-4 bg-blue-500 focus:ring-blue-400 border-gray-300 rounded" :disabled="loading">
          <label for="remember_me" class="ml-2 block text-sm text-gray-800">
            Запомнить
          </label>
        </div>
      </div>
      <div>
        <button @click="try_login" :disabled="loading || (!String(login).trim() && !String(password).trim())" type="submit" class="w-full flex justify-center button primary text-gray-100 p-3 rounded-full tracking-wide font-semibold shadow-lg cursor-pointer transition ease-in duration-200">
          {{ localize('login_action') }}
        </button>
      </div>
    </div>
  </div>
</template>
<script>
export default {
  data: function() {
    return {
      returned_error:'',

      loading:false,
      remember_me:true,
      login:'',
      password:'',
      recaptcha_v3_code: ''
    };
  },
  computed: {
    error_title: function () {
      return localize(this.returned_error);
    }
  },
  methods:{
    localize: function(key) {
      return window.localize(key);
    },
    try_login: function() {
      this.loading = true;
      this.returned_error = '';
      const recaptcha_v2_textarea = this.$el.querySelector('textarea.g-recaptcha-response');

      grecaptcha.ready(() => {
        grecaptcha.execute(recaptcha_v3_site_key, {action: 'submit'}).then(token => {
          this.recaptcha_v3_code = token;

          const payload = {};
          payload.login = this.login;
          payload.password = this.password;
          payload.recaptcha_v3_code = this.recaptcha_v3_code;
          payload.remember_me = this.remember_me;

          if (recaptcha_v2_textarea) {
            payload.recaptcha_v2_code = recaptcha_v2_textarea.value;
          }

          fetch('/account/login', {
            method: 'post',
            body: JSON.stringify(payload)
          })
              .then()
              .then(async server_response => {
                const response = await server_response.json();

                if ('ok' in response) {
                  if (response.ok) {
                    window.location = '/crm';
                  }
                  else if ('error' in response) {
                    this.returned_error = response.error;

                    if (this.returned_error === 'recaptcha_v2_code_required') {
                      const callback_name = 'login_form_recaptcha_v2_code_required_'+Math.random().toString(20).substr(2, 6);
                      window[callback_name] = () => {
                        grecaptcha.render(this.$el.querySelector('.recaptcha-v2-placeholder'), {
                          sitekey: recaptcha_v2_site_key
                        });
                      };

                      ui2.loadScript('https://www.google.com/recaptcha/api.js?onload='+callback_name+'&render=explicit')
                    }
                  } else {
                    this.returned_error = 'unknown_error';
                  }
                }
              })
              .finally(() => {
                this.loading = false;
              })
          ;
        });
      });
    }
  }
};
</script>
<style scoped>
</style>